@@ -2,7 +2,7 @@
 
 """
 Author: Bob Rosbag
-2017
+2020
 
 This plug-in is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ from libqtopensesame.items.qtautoplugin import qtautoplugin
 from libopensesame.exceptions import osexception
 import pygame
 
-VERSION = u'2018.04-1'
+VERSION = u'2020.11-1'
 
 class audio_low_latency_play_init(item):
 
@@ -39,6 +39,7 @@ class audio_low_latency_play_init(item):
 
     # Provide an informative description for your plug-in.
     description = u'Low Latency Audio: initializes the playback audio device.'
+    lazy_init = False
 
     def __init__(self, name, experiment, string=None):
 
@@ -257,7 +258,7 @@ class audio_low_latency_play_init(item):
                 if samplerate_set != self.samplerate:
                     error_msg_list.append(u'Samplerate of %d Hz not supported\n' % (self.samplerate))
                 if period_size_set != self.period_size:
-                    error_msg_list.append(u'Period size of %d frames not supported\n' % (self.period_size))
+                    error_msg_list.append(u'Period size of %d frames not supported. %d frames is recommended.\n' % (self.period_size, period_size_set))
                 if error_msg_list:
                     raise osexception(u'Error with device: %s\n%s' % (self.device_name, ''.join(error_msg_list)))
 
@@ -279,13 +280,11 @@ class audio_low_latency_play_init(item):
                                 output_device_index=self.device_index)
 
                     except Exception as e:
-                        raise osexception(
-                            u'Could not start audio device', exception=e)
+                        raise osexception(u'%dbit audio not supported\n' % (self.bitdepth), exception=e)
 
                 self.show_message(u'Estimated output latency: %fms ' % (self.device.get_output_latency()))
                 self.show_message(u'Buffer size: %d frames ' % (self.device.get_write_available()))
 
-
             elif self.module == self.sounddevice_module_name and self.sounddevice_module_name in self.experiment.audio_low_latency_play_module_list:
                 import sounddevice
 
@@ -406,8 +405,6 @@ class qtaudio_low_latency_play_init(audio_low_latency_play_init, qtautoplugin):
 
         audio_low_latency_play_init.__init__(self, name, experiment, script)
         qtautoplugin.__init__(self, __file__)
-        self.text_version.setText(
-        u'<small>Audio Low Latency version %s</small>' % VERSION)
 
         if self.var.module in self.experiment.audio_low_latency_play_module_list:
             self.current_module = self.var.module
@@ -443,7 +440,7 @@ class qtaudio_low_latency_play_init(audio_low_latency_play_init, qtautoplugin):
         if not qtautoplugin.apply_edit_changes(self) or self.lock:
             return False
         self.custom_interactions()
-
+        return True
 
     def edit_widget(self):
 
