@@ -2,7 +2,7 @@
 
 """
 Author: Bob Rosbag
-2017
+2020
 
 This plug-in is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,10 +27,8 @@ from libqtopensesame.items.qtautoplugin import qtautoplugin
 from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 import wave
-import pygame
 
-
-VERSION = u'2017.11-1'
+VERSION = u'2020.11-1'
 
 class audio_low_latency_record(item):
 
@@ -59,6 +57,7 @@ class audio_low_latency_record(item):
         self.var.bitdepth = str(16)
         self.var.samplerate = str(44100)
         self.var.channels = str(1)
+        self.var.pause_resume = u''
         self.var.ram_cache = u'yes'
 
     def init_var(self):
@@ -75,13 +74,15 @@ class audio_low_latency_record(item):
             self.period_size_time = self.experiment.audio_low_latency_record_period_size_time
             self.data_size = self.experiment.audio_low_latency_record_data_size
             self.bitdepth = self.experiment.audio_low_latency_record_bitdepth
+            self.samplewidth = self.experiment.audio_low_latency_record_samplewidth
             self.samplerate = self.experiment.audio_low_latency_record_samplerate
             self.channels = self.experiment.audio_low_latency_record_channels
         else:
             raise osexception(
                     u'Audio Low Latency Record Init item is missing')
 
-        self.filename = self.var.filename
+        self.filename = self.experiment.pool[self.var.filename]
+        self.pause_resume = self.var.pause_resume
         self.ram_cache = self.var.ram_cache
 
 
@@ -97,6 +98,16 @@ class audio_low_latency_record(item):
 
         self.init_var()
 
+        if self.pause_resume != u'':
+            # Prepare the pause resume responses
+            self._allowed_responses = []
+            for r in safe_decode(self.pause_resume).split(u';'):
+                if r.strip() != u'':
+                    self._allowed_responses.append(r)
+            if not self._allowed_responses:
+                self._allowed_responses = None
+            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses)
+
         if self.dummy_mode == u'no':
             try:
                 self.show_message(u'\n')
@@ -128,7 +139,7 @@ class audio_low_latency_record(item):
                 if self.duration < self.period_size_time:
                     raise osexception(u'Duration should be larger than period duration')
             else:
-                raise osexception(u'Duration can not be negative')
+                raise osexception(u'Duration cannot be negative')
         else:
             raise osexception(u'Duration should be a integer')
 
@@ -144,7 +155,6 @@ class audio_low_latency_record(item):
         else:
             raise osexception(u'Delay should be a integer')
 
-
         if self.dummy_mode == u'no':
             while self.experiment.audio_low_latency_record_locked:
                 self.clock.sleep(self.poll_time)
@@ -155,11 +165,16 @@ class audio_low_latency_record(item):
             else:
                 delay = self.delay
 
-            self.show_message(u'Starting recording audio')
+            self.show_message(u'Starting audio recording')
+
+            if self.pause_resume != u'':
+                self.kb.keylist = self._allowed_responses
+                self.kb.flush()
 
             self.record(self.device, self.wav_file, self.period_size, self.duration, delay)
 
         elif self.dummy_mode == u'yes':
+            self.set_stimulus_onset()
             self.show_message(u'Dummy mode enabled, NOT recording audio')
         else:
             raise osexception(u'Error with dummy mode!')
@@ -193,6 +208,17 @@ class audio_low_latency_record(item):
             elif self.ram_cache == u'no':
                 wav_file.writeframes(data)
 
+            if self.pause_resume != u'':
+                key1, time1 = self.kb.get_key()
+                if key1 in self._allowed_responses:
+                    self.kb.flush()
+                    self.show_message(u'Paused audio recording')
+                    while True:
+                        key2, time2 = self.kb.get_key()
+                        if key2 in self._allowed_responses:
+                            self.show_message(u'Resumed audio recording')
+                            break
+
         self.set_stimulus_offset()
 
         if self.ram_cache == u'yes':
@@ -205,7 +231,7 @@ class audio_low_latency_record(item):
 
         wav_file.close()
 
-        self.show_message(u'Stopped recording audio')
+        self.show_message(u'Stopped audio recording')
         self.experiment.audio_low_latency_record_locked = 0
 
 
@@ -285,6 +311,3 @@ class qtaudio_low_latency_record(audio_low_latency_record, qtautoplugin):
 
         audio_low_latency_record.__init__(self, name, experiment, script)
         qtautoplugin.__init__(self, __file__)
-        self.text_version.setText(
-        u'<small>Audio Low Latency version %s</small>' % VERSION)
-
