@@ -2,7 +2,7 @@
 
 """
 Author: Bob Rosbag
-2017
+2020
 
 This plug-in is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ from libqtopensesame.items.qtautoplugin import qtautoplugin
 from libopensesame.exceptions import osexception
 import pygame
 
-VERSION = u'2018.04-1'
+VERSION = u'2020.11-1'
 
 class audio_low_latency_record_init(item):
 
@@ -39,6 +39,7 @@ class audio_low_latency_record_init(item):
 
     # Provide an informative description for your plug-in.
     description = u'Low Latency Audio: initializes the recording audio device.'
+    lazy_init = False
 
     def __init__(self, name, experiment, string=None):
 
@@ -73,7 +74,7 @@ class audio_low_latency_record_init(item):
         self.experiment.sounddevice_module_name = self.sounddevice_module_name
         self.experiment.pyaudio_module_name = self.pyaudio_module_name
         self.experiment.oss4_module_name = self.oss4_module_name
-                
+
         if os.name == 'posix':
             if u'alsaaudio' in self.modules_enabled:
                 try:
@@ -105,7 +106,7 @@ class audio_low_latency_record_init(item):
                 for di in range(0, len(cards)):
                     sounddevice_cards_dict = cards[di]
                     sounddevice_cards.append(sounddevice_cards_dict['name'])
-                print(sounddevice_cards)
+
                 self.experiment.audio_low_latency_record_device_dict[self.sounddevice_module_name] = sounddevice_cards
                 self.experiment.audio_low_latency_record_device_selected_dict[self.sounddevice_module_name] = sounddevice_cards[0]
 
@@ -257,7 +258,7 @@ class audio_low_latency_record_init(item):
                 if samplerate_set != self.samplerate:
                     error_msg_list.append(u'Samplerate of %d Hz not supported\n' % (self.samplerate))
                 if period_size_set != self.period_size:
-                    error_msg_list.append(u'Period size of %d frames not supported\n' % (self.period_size))
+                    error_msg_list.append(u'Period size of %d frames not supported. %d frames is recommended.\n' % (self.period_size, period_size_set))
                 if error_msg_list:
                     raise osexception(u'Error with device: %s\n%s' % (self.device_name, ''.join(error_msg_list)))
 
@@ -268,8 +269,7 @@ class audio_low_latency_record_init(item):
                 self.device_init = pyaudio.PyAudio()
 
                 if self.bitdepth == 32:
-                    raise osexception(
-                        u'32bit not yet supported')
+                    raise osexception(u'%dbit audio not supported\n' % (self.bitdepth))
                 else:
                     try:
                         self.device = self.device_init.open(format=self.device_init.get_format_from_width(self.samplewidth),
@@ -401,8 +401,6 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
 
         audio_low_latency_record_init.__init__(self, name, experiment, script)
         qtautoplugin.__init__(self, __file__)
-        self.text_version.setText(
-        u'<small>Audio Low Latency version %s</small>' % VERSION)
 
         if self.var.module in self.experiment.audio_low_latency_record_module_list:
             self.current_module = self.var.module
@@ -438,7 +436,7 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
         if not qtautoplugin.apply_edit_changes(self) or self.lock:
             return False
         self.custom_interactions()
-
+        return True
 
     def edit_widget(self):
 
